# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTemplateDetails(object):
    """
    Updates the specified template.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTemplateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateTemplateDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateTemplateDetails.
        :type description: str

        :param long_description:
            The value to assign to the long_description property of this UpdateTemplateDetails.
        :type long_description: str

        :param logo_file_base64_encoded:
            The value to assign to the logo_file_base64_encoded property of this UpdateTemplateDetails.
        :type logo_file_base64_encoded: str

        :param template_config_source:
            The value to assign to the template_config_source property of this UpdateTemplateDetails.
        :type template_config_source: oci.resource_manager.models.UpdateTemplateConfigSourceDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateTemplateDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateTemplateDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'long_description': 'str',
            'logo_file_base64_encoded': 'str',
            'template_config_source': 'UpdateTemplateConfigSourceDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'long_description': 'longDescription',
            'logo_file_base64_encoded': 'logoFileBase64Encoded',
            'template_config_source': 'templateConfigSource',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._long_description = None
        self._logo_file_base64_encoded = None
        self._template_config_source = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateTemplateDetails.
        The template's display name. Avoid entering confidential information.


        :return: The display_name of this UpdateTemplateDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateTemplateDetails.
        The template's display name. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateTemplateDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateTemplateDetails.
        Description of the template. Avoid entering confidential information.


        :return: The description of this UpdateTemplateDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateTemplateDetails.
        Description of the template. Avoid entering confidential information.


        :param description: The description of this UpdateTemplateDetails.
        :type: str
        """
        self._description = description

    @property
    def long_description(self):
        """
        Gets the long_description of this UpdateTemplateDetails.
        Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.


        :return: The long_description of this UpdateTemplateDetails.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this UpdateTemplateDetails.
        Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.


        :param long_description: The long_description of this UpdateTemplateDetails.
        :type: str
        """
        self._long_description = long_description

    @property
    def logo_file_base64_encoded(self):
        """
        Gets the logo_file_base64_encoded of this UpdateTemplateDetails.
        Base64-encoded logo for the template.


        :return: The logo_file_base64_encoded of this UpdateTemplateDetails.
        :rtype: str
        """
        return self._logo_file_base64_encoded

    @logo_file_base64_encoded.setter
    def logo_file_base64_encoded(self, logo_file_base64_encoded):
        """
        Sets the logo_file_base64_encoded of this UpdateTemplateDetails.
        Base64-encoded logo for the template.


        :param logo_file_base64_encoded: The logo_file_base64_encoded of this UpdateTemplateDetails.
        :type: str
        """
        self._logo_file_base64_encoded = logo_file_base64_encoded

    @property
    def template_config_source(self):
        """
        Gets the template_config_source of this UpdateTemplateDetails.

        :return: The template_config_source of this UpdateTemplateDetails.
        :rtype: oci.resource_manager.models.UpdateTemplateConfigSourceDetails
        """
        return self._template_config_source

    @template_config_source.setter
    def template_config_source(self, template_config_source):
        """
        Sets the template_config_source of this UpdateTemplateDetails.

        :param template_config_source: The template_config_source of this UpdateTemplateDetails.
        :type: oci.resource_manager.models.UpdateTemplateConfigSourceDetails
        """
        self._template_config_source = template_config_source

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateTemplateDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateTemplateDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateTemplateDetails.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateTemplateDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateTemplateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateTemplateDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateTemplateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateTemplateDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateNodeShapeConfigDetails(object):
    """
    The shape configuration of the nodes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateNodeShapeConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ocpus:
            The value to assign to the ocpus property of this UpdateNodeShapeConfigDetails.
        :type ocpus: float

        :param memory_in_gbs:
            The value to assign to the memory_in_gbs property of this UpdateNodeShapeConfigDetails.
        :type memory_in_gbs: float

        """
        self.swagger_types = {
            'ocpus': 'float',
            'memory_in_gbs': 'float'
        }

        self.attribute_map = {
            'ocpus': 'ocpus',
            'memory_in_gbs': 'memoryInGBs'
        }

        self._ocpus = None
        self._memory_in_gbs = None

    @property
    def ocpus(self):
        """
        Gets the ocpus of this UpdateNodeShapeConfigDetails.
        The total number of OCPUs available to each node in the node pool.
        See `here`__ for details.

        __ https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/20160918/Shape/


        :return: The ocpus of this UpdateNodeShapeConfigDetails.
        :rtype: float
        """
        return self._ocpus

    @ocpus.setter
    def ocpus(self, ocpus):
        """
        Sets the ocpus of this UpdateNodeShapeConfigDetails.
        The total number of OCPUs available to each node in the node pool.
        See `here`__ for details.

        __ https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/20160918/Shape/


        :param ocpus: The ocpus of this UpdateNodeShapeConfigDetails.
        :type: float
        """
        self._ocpus = ocpus

    @property
    def memory_in_gbs(self):
        """
        Gets the memory_in_gbs of this UpdateNodeShapeConfigDetails.
        The total amount of memory available to each node, in gigabytes.


        :return: The memory_in_gbs of this UpdateNodeShapeConfigDetails.
        :rtype: float
        """
        return self._memory_in_gbs

    @memory_in_gbs.setter
    def memory_in_gbs(self, memory_in_gbs):
        """
        Sets the memory_in_gbs of this UpdateNodeShapeConfigDetails.
        The total amount of memory available to each node, in gigabytes.


        :param memory_in_gbs: The memory_in_gbs of this UpdateNodeShapeConfigDetails.
        :type: float
        """
        self._memory_in_gbs = memory_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryDefinition(object):
    """
    The common fields for queries.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this QueryDefinition.
        :type display_name: str

        :param report_query:
            The value to assign to the report_query property of this QueryDefinition.
        :type report_query: oci.usage_api.models.ReportQuery

        :param cost_analysis_ui:
            The value to assign to the cost_analysis_ui property of this QueryDefinition.
        :type cost_analysis_ui: oci.usage_api.models.CostAnalysisUI

        :param version:
            The value to assign to the version property of this QueryDefinition.
        :type version: float

        """
        self.swagger_types = {
            'display_name': 'str',
            'report_query': 'ReportQuery',
            'cost_analysis_ui': 'CostAnalysisUI',
            'version': 'float'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'report_query': 'reportQuery',
            'cost_analysis_ui': 'costAnalysisUI',
            'version': 'version'
        }

        self._display_name = None
        self._report_query = None
        self._cost_analysis_ui = None
        self._version = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this QueryDefinition.
        The query display name. Avoid entering confidential information.


        :return: The display_name of this QueryDefinition.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this QueryDefinition.
        The query display name. Avoid entering confidential information.


        :param display_name: The display_name of this QueryDefinition.
        :type: str
        """
        self._display_name = display_name

    @property
    def report_query(self):
        """
        **[Required]** Gets the report_query of this QueryDefinition.

        :return: The report_query of this QueryDefinition.
        :rtype: oci.usage_api.models.ReportQuery
        """
        return self._report_query

    @report_query.setter
    def report_query(self, report_query):
        """
        Sets the report_query of this QueryDefinition.

        :param report_query: The report_query of this QueryDefinition.
        :type: oci.usage_api.models.ReportQuery
        """
        self._report_query = report_query

    @property
    def cost_analysis_ui(self):
        """
        **[Required]** Gets the cost_analysis_ui of this QueryDefinition.

        :return: The cost_analysis_ui of this QueryDefinition.
        :rtype: oci.usage_api.models.CostAnalysisUI
        """
        return self._cost_analysis_ui

    @cost_analysis_ui.setter
    def cost_analysis_ui(self, cost_analysis_ui):
        """
        Sets the cost_analysis_ui of this QueryDefinition.

        :param cost_analysis_ui: The cost_analysis_ui of this QueryDefinition.
        :type: oci.usage_api.models.CostAnalysisUI
        """
        self._cost_analysis_ui = cost_analysis_ui

    @property
    def version(self):
        """
        **[Required]** Gets the version of this QueryDefinition.
        The saved query version.


        :return: The version of this QueryDefinition.
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this QueryDefinition.
        The saved query version.


        :param version: The version of this QueryDefinition.
        :type: float
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostCisBenchmarkScanResultSummary(object):
    """
    A summary of a result for all CIS (Center for Internet Security) benchmark execution for this host
    """

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a HostCisBenchmarkScanResultSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new HostCisBenchmarkScanResultSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this HostCisBenchmarkScanResultSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this HostCisBenchmarkScanResultSummary.
        :type display_name: str

        :param instance_id:
            The value to assign to the instance_id property of this HostCisBenchmarkScanResultSummary.
        :type instance_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this HostCisBenchmarkScanResultSummary.
        :type compartment_id: str

        :param time_started:
            The value to assign to the time_started property of this HostCisBenchmarkScanResultSummary.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this HostCisBenchmarkScanResultSummary.
        :type time_finished: datetime

        :param cis_benchmark_scan_issues_count:
            The value to assign to the cis_benchmark_scan_issues_count property of this HostCisBenchmarkScanResultSummary.
        :type cis_benchmark_scan_issues_count: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this HostCisBenchmarkScanResultSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'instance_id': 'str',
            'compartment_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'cis_benchmark_scan_issues_count': 'int',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'instance_id': 'instanceId',
            'compartment_id': 'compartmentId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'cis_benchmark_scan_issues_count': 'cisBenchmarkScanIssuesCount',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._display_name = None
        self._instance_id = None
        self._compartment_id = None
        self._time_started = None
        self._time_finished = None
        self._cis_benchmark_scan_issues_count = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this HostCisBenchmarkScanResultSummary.
        Unique identifier of the scan


        :return: The id of this HostCisBenchmarkScanResultSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HostCisBenchmarkScanResultSummary.
        Unique identifier of the scan


        :param id: The id of this HostCisBenchmarkScanResultSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this HostCisBenchmarkScanResultSummary.
        Name of the resource


        :return: The display_name of this HostCisBenchmarkScanResultSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this HostCisBenchmarkScanResultSummary.
        Name of the resource


        :param display_name: The display_name of this HostCisBenchmarkScanResultSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this HostCisBenchmarkScanResultSummary.
        Instance ID of the Compute Instance scanned


        :return: The instance_id of this HostCisBenchmarkScanResultSummary.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this HostCisBenchmarkScanResultSummary.
        Instance ID of the Compute Instance scanned


        :param instance_id: The instance_id of this HostCisBenchmarkScanResultSummary.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this HostCisBenchmarkScanResultSummary.
        Compartment ID of the resource. This is set to the same as the compartment ID of the scan target


        :return: The compartment_id of this HostCisBenchmarkScanResultSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this HostCisBenchmarkScanResultSummary.
        Compartment ID of the resource. This is set to the same as the compartment ID of the scan target


        :param compartment_id: The compartment_id of this HostCisBenchmarkScanResultSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this HostCisBenchmarkScanResultSummary.
        Date and time the scan was started, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_started of this HostCisBenchmarkScanResultSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this HostCisBenchmarkScanResultSummary.
        Date and time the scan was started, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_started: The time_started of this HostCisBenchmarkScanResultSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        **[Required]** Gets the time_finished of this HostCisBenchmarkScanResultSummary.
        Date and time the scan was completed, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_finished of this HostCisBenchmarkScanResultSummary.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this HostCisBenchmarkScanResultSummary.
        Date and time the scan was completed, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_finished: The time_finished of this HostCisBenchmarkScanResultSummary.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def cis_benchmark_scan_issues_count(self):
        """
        **[Required]** Gets the cis_benchmark_scan_issues_count of this HostCisBenchmarkScanResultSummary.
        Total number of CIS (Center for Internet Security) benchmark issues found in this scan


        :return: The cis_benchmark_scan_issues_count of this HostCisBenchmarkScanResultSummary.
        :rtype: int
        """
        return self._cis_benchmark_scan_issues_count

    @cis_benchmark_scan_issues_count.setter
    def cis_benchmark_scan_issues_count(self, cis_benchmark_scan_issues_count):
        """
        Sets the cis_benchmark_scan_issues_count of this HostCisBenchmarkScanResultSummary.
        Total number of CIS (Center for Internet Security) benchmark issues found in this scan


        :param cis_benchmark_scan_issues_count: The cis_benchmark_scan_issues_count of this HostCisBenchmarkScanResultSummary.
        :type: int
        """
        self._cis_benchmark_scan_issues_count = cis_benchmark_scan_issues_count

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this HostCisBenchmarkScanResultSummary.
        The current state of the result.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this HostCisBenchmarkScanResultSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this HostCisBenchmarkScanResultSummary.
        The current state of the result.


        :param lifecycle_state: The lifecycle_state of this HostCisBenchmarkScanResultSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostCisBenchmarkScanResultScore(object):
    """
    A single CIS (Center for Internet Security) benchmark executed in a host scan
    """

    #: A constant which can be used with the score property of a HostCisBenchmarkScanResultScore.
    #: This constant has a value of "PASS"
    SCORE_PASS = "PASS"

    #: A constant which can be used with the score property of a HostCisBenchmarkScanResultScore.
    #: This constant has a value of "FAIL"
    SCORE_FAIL = "FAIL"

    def __init__(self, **kwargs):
        """
        Initializes a new HostCisBenchmarkScanResultScore object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param benchmark_identifier:
            The value to assign to the benchmark_identifier property of this HostCisBenchmarkScanResultScore.
        :type benchmark_identifier: str

        :param description:
            The value to assign to the description property of this HostCisBenchmarkScanResultScore.
        :type description: str

        :param score:
            The value to assign to the score property of this HostCisBenchmarkScanResultScore.
            Allowed values for this property are: "PASS", "FAIL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type score: str

        """
        self.swagger_types = {
            'benchmark_identifier': 'str',
            'description': 'str',
            'score': 'str'
        }

        self.attribute_map = {
            'benchmark_identifier': 'benchmarkIdentifier',
            'description': 'description',
            'score': 'score'
        }

        self._benchmark_identifier = None
        self._description = None
        self._score = None

    @property
    def benchmark_identifier(self):
        """
        **[Required]** Gets the benchmark_identifier of this HostCisBenchmarkScanResultScore.
        Identifier for this CIS (Center for Internet Security) benchmark


        :return: The benchmark_identifier of this HostCisBenchmarkScanResultScore.
        :rtype: str
        """
        return self._benchmark_identifier

    @benchmark_identifier.setter
    def benchmark_identifier(self, benchmark_identifier):
        """
        Sets the benchmark_identifier of this HostCisBenchmarkScanResultScore.
        Identifier for this CIS (Center for Internet Security) benchmark


        :param benchmark_identifier: The benchmark_identifier of this HostCisBenchmarkScanResultScore.
        :type: str
        """
        self._benchmark_identifier = benchmark_identifier

    @property
    def description(self):
        """
        **[Required]** Gets the description of this HostCisBenchmarkScanResultScore.
        Details about what this CIS (Center for Internet Security) benchmark represents


        :return: The description of this HostCisBenchmarkScanResultScore.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this HostCisBenchmarkScanResultScore.
        Details about what this CIS (Center for Internet Security) benchmark represents


        :param description: The description of this HostCisBenchmarkScanResultScore.
        :type: str
        """
        self._description = description

    @property
    def score(self):
        """
        **[Required]** Gets the score of this HostCisBenchmarkScanResultScore.
        Result score of CIS (Center for Internet Security) benchmark execution (Pass/Fail)

        Allowed values for this property are: "PASS", "FAIL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The score of this HostCisBenchmarkScanResultScore.
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this HostCisBenchmarkScanResultScore.
        Result score of CIS (Center for Internet Security) benchmark execution (Pass/Fail)


        :param score: The score of this HostCisBenchmarkScanResultScore.
        :type: str
        """
        allowed_values = ["PASS", "FAIL"]
        if not value_allowed_none_or_none_sentinel(score, allowed_values):
            score = 'UNKNOWN_ENUM_VALUE'
        self._score = score

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTaskScheduleDetails(object):
    """
    The update task details.
    """

    #: A constant which can be used with the retry_delay_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "SECONDS"
    RETRY_DELAY_UNIT_SECONDS = "SECONDS"

    #: A constant which can be used with the retry_delay_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "MINUTES"
    RETRY_DELAY_UNIT_MINUTES = "MINUTES"

    #: A constant which can be used with the retry_delay_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "HOURS"
    RETRY_DELAY_UNIT_HOURS = "HOURS"

    #: A constant which can be used with the retry_delay_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "DAYS"
    RETRY_DELAY_UNIT_DAYS = "DAYS"

    #: A constant which can be used with the auth_mode property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "OBO"
    AUTH_MODE_OBO = "OBO"

    #: A constant which can be used with the auth_mode property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "RESOURCE_PRINCIPAL"
    AUTH_MODE_RESOURCE_PRINCIPAL = "RESOURCE_PRINCIPAL"

    #: A constant which can be used with the auth_mode property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "USER_CERTIFICATE"
    AUTH_MODE_USER_CERTIFICATE = "USER_CERTIFICATE"

    #: A constant which can be used with the expected_duration_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "SECONDS"
    EXPECTED_DURATION_UNIT_SECONDS = "SECONDS"

    #: A constant which can be used with the expected_duration_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "MINUTES"
    EXPECTED_DURATION_UNIT_MINUTES = "MINUTES"

    #: A constant which can be used with the expected_duration_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "HOURS"
    EXPECTED_DURATION_UNIT_HOURS = "HOURS"

    #: A constant which can be used with the expected_duration_unit property of a UpdateTaskScheduleDetails.
    #: This constant has a value of "DAYS"
    EXPECTED_DURATION_UNIT_DAYS = "DAYS"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTaskScheduleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this UpdateTaskScheduleDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this UpdateTaskScheduleDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this UpdateTaskScheduleDetails.
        :type model_type: str

        :param parent_ref:
            The value to assign to the parent_ref property of this UpdateTaskScheduleDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this UpdateTaskScheduleDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateTaskScheduleDetails.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this UpdateTaskScheduleDetails.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this UpdateTaskScheduleDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this UpdateTaskScheduleDetails.
        :type identifier: str

        :param schedule_ref:
            The value to assign to the schedule_ref property of this UpdateTaskScheduleDetails.
        :type schedule_ref: oci.data_integration.models.Schedule

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this UpdateTaskScheduleDetails.
        :type config_provider_delegate: oci.data_integration.models.ConfigProvider

        :param is_enabled:
            The value to assign to the is_enabled property of this UpdateTaskScheduleDetails.
        :type is_enabled: bool

        :param number_of_retries:
            The value to assign to the number_of_retries property of this UpdateTaskScheduleDetails.
        :type number_of_retries: int

        :param retry_delay:
            The value to assign to the retry_delay property of this UpdateTaskScheduleDetails.
        :type retry_delay: float

        :param retry_delay_unit:
            The value to assign to the retry_delay_unit property of this UpdateTaskScheduleDetails.
            Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS"
        :type retry_delay_unit: str

        :param start_time_millis:
            The value to assign to the start_time_millis property of this UpdateTaskScheduleDetails.
        :type start_time_millis: int

        :param end_time_millis:
            The value to assign to the end_time_millis property of this UpdateTaskScheduleDetails.
        :type end_time_millis: int

        :param is_concurrent_allowed:
            The value to assign to the is_concurrent_allowed property of this UpdateTaskScheduleDetails.
        :type is_concurrent_allowed: bool

        :param is_backfill_enabled:
            The value to assign to the is_backfill_enabled property of this UpdateTaskScheduleDetails.
        :type is_backfill_enabled: bool

        :param auth_mode:
            The value to assign to the auth_mode property of this UpdateTaskScheduleDetails.
            Allowed values for this property are: "OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE"
        :type auth_mode: str

        :param expected_duration:
            The value to assign to the expected_duration property of this UpdateTaskScheduleDetails.
        :type expected_duration: float

        :param expected_duration_unit:
            The value to assign to the expected_duration_unit property of this UpdateTaskScheduleDetails.
            Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS"
        :type expected_duration_unit: str

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateTaskScheduleDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'model_type': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'schedule_ref': 'Schedule',
            'config_provider_delegate': 'ConfigProvider',
            'is_enabled': 'bool',
            'number_of_retries': 'int',
            'retry_delay': 'float',
            'retry_delay_unit': 'str',
            'start_time_millis': 'int',
            'end_time_millis': 'int',
            'is_concurrent_allowed': 'bool',
            'is_backfill_enabled': 'bool',
            'auth_mode': 'str',
            'expected_duration': 'float',
            'expected_duration_unit': 'str',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'schedule_ref': 'scheduleRef',
            'config_provider_delegate': 'configProviderDelegate',
            'is_enabled': 'isEnabled',
            'number_of_retries': 'numberOfRetries',
            'retry_delay': 'retryDelay',
            'retry_delay_unit': 'retryDelayUnit',
            'start_time_millis': 'startTimeMillis',
            'end_time_millis': 'endTimeMillis',
            'is_concurrent_allowed': 'isConcurrentAllowed',
            'is_backfill_enabled': 'isBackfillEnabled',
            'auth_mode': 'authMode',
            'expected_duration': 'expectedDuration',
            'expected_duration_unit': 'expectedDurationUnit',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_version = None
        self._model_type = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._schedule_ref = None
        self._config_provider_delegate = None
        self._is_enabled = None
        self._number_of_retries = None
        self._retry_delay = None
        self._retry_delay_unit = None
        self._start_time_millis = None
        self._end_time_millis = None
        self._is_concurrent_allowed = None
        self._is_backfill_enabled = None
        self._auth_mode = None
        self._expected_duration = None
        self._expected_duration_unit = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this UpdateTaskScheduleDetails.
        Generated key that can be used in API calls to identify taskSchedule. On scenarios where reference to the taskSchedule is needed, a value can be passed in create.


        :return: The key of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this UpdateTaskScheduleDetails.
        Generated key that can be used in API calls to identify taskSchedule. On scenarios where reference to the taskSchedule is needed, a value can be passed in create.


        :param key: The key of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateTaskScheduleDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :return: The model_version of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateTaskScheduleDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :param model_version: The model_version of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this UpdateTaskScheduleDetails.
        The type of the object.


        :return: The model_type of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this UpdateTaskScheduleDetails.
        The type of the object.


        :param model_type: The model_type of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this UpdateTaskScheduleDetails.

        :return: The parent_ref of this UpdateTaskScheduleDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this UpdateTaskScheduleDetails.

        :param parent_ref: The parent_ref of this UpdateTaskScheduleDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this UpdateTaskScheduleDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateTaskScheduleDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UpdateTaskScheduleDetails.
        Detailed description for the object.


        :return: The description of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateTaskScheduleDetails.
        Detailed description for the object.


        :param description: The description of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        **[Required]** Gets the object_version of this UpdateTaskScheduleDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :return: The object_version of this UpdateTaskScheduleDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateTaskScheduleDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :param object_version: The object_version of this UpdateTaskScheduleDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateTaskScheduleDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateTaskScheduleDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateTaskScheduleDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateTaskScheduleDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateTaskScheduleDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateTaskScheduleDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateTaskScheduleDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def schedule_ref(self):
        """
        Gets the schedule_ref of this UpdateTaskScheduleDetails.

        :return: The schedule_ref of this UpdateTaskScheduleDetails.
        :rtype: oci.data_integration.models.Schedule
        """
        return self._schedule_ref

    @schedule_ref.setter
    def schedule_ref(self, schedule_ref):
        """
        Sets the schedule_ref of this UpdateTaskScheduleDetails.

        :param schedule_ref: The schedule_ref of this UpdateTaskScheduleDetails.
        :type: oci.data_integration.models.Schedule
        """
        self._schedule_ref = schedule_ref

    @property
    def config_provider_delegate(self):
        """
        Gets the config_provider_delegate of this UpdateTaskScheduleDetails.

        :return: The config_provider_delegate of this UpdateTaskScheduleDetails.
        :rtype: oci.data_integration.models.ConfigProvider
        """
        return self._config_provider_delegate

    @config_provider_delegate.setter
    def config_provider_delegate(self, config_provider_delegate):
        """
        Sets the config_provider_delegate of this UpdateTaskScheduleDetails.

        :param config_provider_delegate: The config_provider_delegate of this UpdateTaskScheduleDetails.
        :type: oci.data_integration.models.ConfigProvider
        """
        self._config_provider_delegate = config_provider_delegate

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this UpdateTaskScheduleDetails.
        enabled


        :return: The is_enabled of this UpdateTaskScheduleDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this UpdateTaskScheduleDetails.
        enabled


        :param is_enabled: The is_enabled of this UpdateTaskScheduleDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def number_of_retries(self):
        """
        Gets the number_of_retries of this UpdateTaskScheduleDetails.
        The number of retries.


        :return: The number_of_retries of this UpdateTaskScheduleDetails.
        :rtype: int
        """
        return self._number_of_retries

    @number_of_retries.setter
    def number_of_retries(self, number_of_retries):
        """
        Sets the number_of_retries of this UpdateTaskScheduleDetails.
        The number of retries.


        :param number_of_retries: The number_of_retries of this UpdateTaskScheduleDetails.
        :type: int
        """
        self._number_of_retries = number_of_retries

    @property
    def retry_delay(self):
        """
        Gets the retry_delay of this UpdateTaskScheduleDetails.
        The retry delay, the unit for measurement is in the property retry delay unit.


        :return: The retry_delay of this UpdateTaskScheduleDetails.
        :rtype: float
        """
        return self._retry_delay

    @retry_delay.setter
    def retry_delay(self, retry_delay):
        """
        Sets the retry_delay of this UpdateTaskScheduleDetails.
        The retry delay, the unit for measurement is in the property retry delay unit.


        :param retry_delay: The retry_delay of this UpdateTaskScheduleDetails.
        :type: float
        """
        self._retry_delay = retry_delay

    @property
    def retry_delay_unit(self):
        """
        Gets the retry_delay_unit of this UpdateTaskScheduleDetails.
        The unit for the retry delay.

        Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS"


        :return: The retry_delay_unit of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._retry_delay_unit

    @retry_delay_unit.setter
    def retry_delay_unit(self, retry_delay_unit):
        """
        Sets the retry_delay_unit of this UpdateTaskScheduleDetails.
        The unit for the retry delay.


        :param retry_delay_unit: The retry_delay_unit of this UpdateTaskScheduleDetails.
        :type: str
        """
        allowed_values = ["SECONDS", "MINUTES", "HOURS", "DAYS"]
        if not value_allowed_none_or_none_sentinel(retry_delay_unit, allowed_values):
            raise ValueError(
                "Invalid value for `retry_delay_unit`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._retry_delay_unit = retry_delay_unit

    @property
    def start_time_millis(self):
        """
        Gets the start_time_millis of this UpdateTaskScheduleDetails.
        The start time in milliseconds.


        :return: The start_time_millis of this UpdateTaskScheduleDetails.
        :rtype: int
        """
        return self._start_time_millis

    @start_time_millis.setter
    def start_time_millis(self, start_time_millis):
        """
        Sets the start_time_millis of this UpdateTaskScheduleDetails.
        The start time in milliseconds.


        :param start_time_millis: The start_time_millis of this UpdateTaskScheduleDetails.
        :type: int
        """
        self._start_time_millis = start_time_millis

    @property
    def end_time_millis(self):
        """
        Gets the end_time_millis of this UpdateTaskScheduleDetails.
        The end time in milliseconds.


        :return: The end_time_millis of this UpdateTaskScheduleDetails.
        :rtype: int
        """
        return self._end_time_millis

    @end_time_millis.setter
    def end_time_millis(self, end_time_millis):
        """
        Sets the end_time_millis of this UpdateTaskScheduleDetails.
        The end time in milliseconds.


        :param end_time_millis: The end_time_millis of this UpdateTaskScheduleDetails.
        :type: int
        """
        self._end_time_millis = end_time_millis

    @property
    def is_concurrent_allowed(self):
        """
        Gets the is_concurrent_allowed of this UpdateTaskScheduleDetails.
        Whether the same task can be executed concurrently.


        :return: The is_concurrent_allowed of this UpdateTaskScheduleDetails.
        :rtype: bool
        """
        return self._is_concurrent_allowed

    @is_concurrent_allowed.setter
    def is_concurrent_allowed(self, is_concurrent_allowed):
        """
        Sets the is_concurrent_allowed of this UpdateTaskScheduleDetails.
        Whether the same task can be executed concurrently.


        :param is_concurrent_allowed: The is_concurrent_allowed of this UpdateTaskScheduleDetails.
        :type: bool
        """
        self._is_concurrent_allowed = is_concurrent_allowed

    @property
    def is_backfill_enabled(self):
        """
        Gets the is_backfill_enabled of this UpdateTaskScheduleDetails.
        Whether the backfill is enabled.


        :return: The is_backfill_enabled of this UpdateTaskScheduleDetails.
        :rtype: bool
        """
        return self._is_backfill_enabled

    @is_backfill_enabled.setter
    def is_backfill_enabled(self, is_backfill_enabled):
        """
        Sets the is_backfill_enabled of this UpdateTaskScheduleDetails.
        Whether the backfill is enabled.


        :param is_backfill_enabled: The is_backfill_enabled of this UpdateTaskScheduleDetails.
        :type: bool
        """
        self._is_backfill_enabled = is_backfill_enabled

    @property
    def auth_mode(self):
        """
        Gets the auth_mode of this UpdateTaskScheduleDetails.
        The authorization mode for the task.

        Allowed values for this property are: "OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE"


        :return: The auth_mode of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._auth_mode

    @auth_mode.setter
    def auth_mode(self, auth_mode):
        """
        Sets the auth_mode of this UpdateTaskScheduleDetails.
        The authorization mode for the task.


        :param auth_mode: The auth_mode of this UpdateTaskScheduleDetails.
        :type: str
        """
        allowed_values = ["OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE"]
        if not value_allowed_none_or_none_sentinel(auth_mode, allowed_values):
            raise ValueError(
                "Invalid value for `auth_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._auth_mode = auth_mode

    @property
    def expected_duration(self):
        """
        Gets the expected_duration of this UpdateTaskScheduleDetails.
        The expected duration of the task.


        :return: The expected_duration of this UpdateTaskScheduleDetails.
        :rtype: float
        """
        return self._expected_duration

    @expected_duration.setter
    def expected_duration(self, expected_duration):
        """
        Sets the expected_duration of this UpdateTaskScheduleDetails.
        The expected duration of the task.


        :param expected_duration: The expected_duration of this UpdateTaskScheduleDetails.
        :type: float
        """
        self._expected_duration = expected_duration

    @property
    def expected_duration_unit(self):
        """
        Gets the expected_duration_unit of this UpdateTaskScheduleDetails.
        The expected duration of the task.

        Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS"


        :return: The expected_duration_unit of this UpdateTaskScheduleDetails.
        :rtype: str
        """
        return self._expected_duration_unit

    @expected_duration_unit.setter
    def expected_duration_unit(self, expected_duration_unit):
        """
        Sets the expected_duration_unit of this UpdateTaskScheduleDetails.
        The expected duration of the task.


        :param expected_duration_unit: The expected_duration_unit of this UpdateTaskScheduleDetails.
        :type: str
        """
        allowed_values = ["SECONDS", "MINUTES", "HOURS", "DAYS"]
        if not value_allowed_none_or_none_sentinel(expected_duration_unit, allowed_values):
            raise ValueError(
                "Invalid value for `expected_duration_unit`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._expected_duration_unit = expected_duration_unit

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateTaskScheduleDetails.

        :return: The registry_metadata of this UpdateTaskScheduleDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateTaskScheduleDetails.

        :param registry_metadata: The registry_metadata of this UpdateTaskScheduleDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostEndpointProtectionScanResultEndpointProtection(object):
    """
    An endpoint protection found in a host scan
    """

    #: A constant which can be used with the severity property of a HostEndpointProtectionScanResultEndpointProtection.
    #: This constant has a value of "NONE"
    SEVERITY_NONE = "NONE"

    #: A constant which can be used with the severity property of a HostEndpointProtectionScanResultEndpointProtection.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a HostEndpointProtectionScanResultEndpointProtection.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a HostEndpointProtectionScanResultEndpointProtection.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a HostEndpointProtectionScanResultEndpointProtection.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    def __init__(self, **kwargs):
        """
        Initializes a new HostEndpointProtectionScanResultEndpointProtection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service:
            The value to assign to the service property of this HostEndpointProtectionScanResultEndpointProtection.
        :type service: str

        :param configuration_finding:
            The value to assign to the configuration_finding property of this HostEndpointProtectionScanResultEndpointProtection.
        :type configuration_finding: str

        :param time_signature_updated:
            The value to assign to the time_signature_updated property of this HostEndpointProtectionScanResultEndpointProtection.
        :type time_signature_updated: datetime

        :param severity:
            The value to assign to the severity property of this HostEndpointProtectionScanResultEndpointProtection.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        """
        self.swagger_types = {
            'service': 'str',
            'configuration_finding': 'str',
            'time_signature_updated': 'datetime',
            'severity': 'str'
        }

        self.attribute_map = {
            'service': 'service',
            'configuration_finding': 'configurationFinding',
            'time_signature_updated': 'timeSignatureUpdated',
            'severity': 'severity'
        }

        self._service = None
        self._configuration_finding = None
        self._time_signature_updated = None
        self._severity = None

    @property
    def service(self):
        """
        **[Required]** Gets the service of this HostEndpointProtectionScanResultEndpointProtection.
        Name of endpoint protection service


        :return: The service of this HostEndpointProtectionScanResultEndpointProtection.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this HostEndpointProtectionScanResultEndpointProtection.
        Name of endpoint protection service


        :param service: The service of this HostEndpointProtectionScanResultEndpointProtection.
        :type: str
        """
        self._service = service

    @property
    def configuration_finding(self):
        """
        **[Required]** Gets the configuration_finding of this HostEndpointProtectionScanResultEndpointProtection.
        Configuration information for endpoint protection service at the time of scan


        :return: The configuration_finding of this HostEndpointProtectionScanResultEndpointProtection.
        :rtype: str
        """
        return self._configuration_finding

    @configuration_finding.setter
    def configuration_finding(self, configuration_finding):
        """
        Sets the configuration_finding of this HostEndpointProtectionScanResultEndpointProtection.
        Configuration information for endpoint protection service at the time of scan


        :param configuration_finding: The configuration_finding of this HostEndpointProtectionScanResultEndpointProtection.
        :type: str
        """
        self._configuration_finding = configuration_finding

    @property
    def time_signature_updated(self):
        """
        **[Required]** Gets the time_signature_updated of this HostEndpointProtectionScanResultEndpointProtection.
        Date and time endpoint protection signature was updated, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_signature_updated of this HostEndpointProtectionScanResultEndpointProtection.
        :rtype: datetime
        """
        return self._time_signature_updated

    @time_signature_updated.setter
    def time_signature_updated(self, time_signature_updated):
        """
        Sets the time_signature_updated of this HostEndpointProtectionScanResultEndpointProtection.
        Date and time endpoint protection signature was updated, as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_signature_updated: The time_signature_updated of this HostEndpointProtectionScanResultEndpointProtection.
        :type: datetime
        """
        self._time_signature_updated = time_signature_updated

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this HostEndpointProtectionScanResultEndpointProtection.
        Problem severity

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this HostEndpointProtectionScanResultEndpointProtection.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this HostEndpointProtectionScanResultEndpointProtection.
        Problem severity


        :param severity: The severity of this HostEndpointProtectionScanResultEndpointProtection.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SavedScheduleReport(object):
    """
    notification to customer.
    """

    #: A constant which can be used with the notification_type property of a SavedScheduleReport.
    #: This constant has a value of "EMAIL"
    NOTIFICATION_TYPE_EMAIL = "EMAIL"

    def __init__(self, **kwargs):
        """
        Initializes a new SavedScheduleReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this SavedScheduleReport.
        :type display_name: str

        :param notification_type:
            The value to assign to the notification_type property of this SavedScheduleReport.
            Allowed values for this property are: "EMAIL"
        :type notification_type: str

        :param notification_target:
            The value to assign to the notification_target property of this SavedScheduleReport.
        :type notification_target: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'notification_type': 'str',
            'notification_target': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'notification_type': 'notificationType',
            'notification_target': 'notificationTarget'
        }

        self._display_name = None
        self._notification_type = None
        self._notification_target = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SavedScheduleReport.
        the name of notification


        :return: The display_name of this SavedScheduleReport.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SavedScheduleReport.
        the name of notification


        :param display_name: The display_name of this SavedScheduleReport.
        :type: str
        """
        self._display_name = display_name

    @property
    def notification_type(self):
        """
        Gets the notification_type of this SavedScheduleReport.
        notification type, eg EMAIL.

        Allowed values for this property are: "EMAIL"


        :return: The notification_type of this SavedScheduleReport.
        :rtype: str
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """
        Sets the notification_type of this SavedScheduleReport.
        notification type, eg EMAIL.


        :param notification_type: The notification_type of this SavedScheduleReport.
        :type: str
        """
        allowed_values = ["EMAIL"]
        if not value_allowed_none_or_none_sentinel(notification_type, allowed_values):
            raise ValueError(
                "Invalid value for `notification_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._notification_type = notification_type

    @property
    def notification_target(self):
        """
        Gets the notification_target of this SavedScheduleReport.
        notification destination.


        :return: The notification_target of this SavedScheduleReport.
        :rtype: str
        """
        return self._notification_target

    @notification_target.setter
    def notification_target(self, notification_target):
        """
        Sets the notification_target of this SavedScheduleReport.
        notification destination.


        :param notification_target: The notification_target of this SavedScheduleReport.
        :type: str
        """
        self._notification_target = notification_target

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublicKeyDetails(object):
    """
    Public key details for a bastion session.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PublicKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param public_key_content:
            The value to assign to the public_key_content property of this PublicKeyDetails.
        :type public_key_content: str

        """
        self.swagger_types = {
            'public_key_content': 'str'
        }

        self.attribute_map = {
            'public_key_content': 'publicKeyContent'
        }

        self._public_key_content = None

    @property
    def public_key_content(self):
        """
        **[Required]** Gets the public_key_content of this PublicKeyDetails.
        The public key in OpenSSH format of the SSH key pair for the session. When you connect to the session, you must provide the private key of the same SSH key pair.


        :return: The public_key_content of this PublicKeyDetails.
        :rtype: str
        """
        return self._public_key_content

    @public_key_content.setter
    def public_key_content(self, public_key_content):
        """
        Sets the public_key_content of this PublicKeyDetails.
        The public key in OpenSSH format of the SSH key pair for the session. When you connect to the session, you must provide the private key of the same SSH key pair.


        :param public_key_content: The public_key_content of this PublicKeyDetails.
        :type: str
        """
        self._public_key_content = public_key_content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceCount(object):
    """
    The count of resources in a category, grouped by status.
    """

    #: A constant which can be used with the status property of a ResourceCount.
    #: This constant has a value of "PENDING"
    STATUS_PENDING = "PENDING"

    #: A constant which can be used with the status property of a ResourceCount.
    #: This constant has a value of "DISMISSED"
    STATUS_DISMISSED = "DISMISSED"

    #: A constant which can be used with the status property of a ResourceCount.
    #: This constant has a value of "POSTPONED"
    STATUS_POSTPONED = "POSTPONED"

    #: A constant which can be used with the status property of a ResourceCount.
    #: This constant has a value of "IMPLEMENTED"
    STATUS_IMPLEMENTED = "IMPLEMENTED"

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceCount object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this ResourceCount.
            Allowed values for this property are: "PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param count:
            The value to assign to the count property of this ResourceCount.
        :type count: int

        """
        self.swagger_types = {
            'status': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'status': 'status',
            'count': 'count'
        }

        self._status = None
        self._count = None

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ResourceCount.
        The recommendation status of the resource.

        Allowed values for this property are: "PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ResourceCount.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ResourceCount.
        The recommendation status of the resource.


        :param status: The status of this ResourceCount.
        :type: str
        """
        allowed_values = ["PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def count(self):
        """
        **[Required]** Gets the count of this ResourceCount.
        The count of resources.


        :return: The count of this ResourceCount.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ResourceCount.
        The count of resources.


        :param count: The count of this ResourceCount.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .response_cache_store_policy import ResponseCacheStorePolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FixedTTLResponseCacheStorePolicy(ResponseCacheStorePolicy):
    """
    How a response from a backend is cached in the Response Cache.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FixedTTLResponseCacheStorePolicy object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.FixedTTLResponseCacheStorePolicy.type` attribute
        of this class is ``FIXED_TTL_STORE_POLICY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this FixedTTLResponseCacheStorePolicy.
            Allowed values for this property are: "FIXED_TTL_STORE_POLICY"
        :type type: str

        :param time_to_live_in_seconds:
            The value to assign to the time_to_live_in_seconds property of this FixedTTLResponseCacheStorePolicy.
        :type time_to_live_in_seconds: int

        """
        self.swagger_types = {
            'type': 'str',
            'time_to_live_in_seconds': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'time_to_live_in_seconds': 'timeToLiveInSeconds'
        }

        self._type = None
        self._time_to_live_in_seconds = None
        self._type = 'FIXED_TTL_STORE_POLICY'

    @property
    def time_to_live_in_seconds(self):
        """
        **[Required]** Gets the time_to_live_in_seconds of this FixedTTLResponseCacheStorePolicy.
        Sets the number of seconds for a response from a backend being stored in the Response Cache before it expires.


        :return: The time_to_live_in_seconds of this FixedTTLResponseCacheStorePolicy.
        :rtype: int
        """
        return self._time_to_live_in_seconds

    @time_to_live_in_seconds.setter
    def time_to_live_in_seconds(self, time_to_live_in_seconds):
        """
        Sets the time_to_live_in_seconds of this FixedTTLResponseCacheStorePolicy.
        Sets the number of seconds for a response from a backend being stored in the Response Cache before it expires.


        :param time_to_live_in_seconds: The time_to_live_in_seconds of this FixedTTLResponseCacheStorePolicy.
        :type: int
        """
        self._time_to_live_in_seconds = time_to_live_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deploy_stage_execution_progress import DeployStageExecutionProgress
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceGroupCanaryDeployStageExecutionProgress(DeployStageExecutionProgress):
    """
    Specifies the Instance Group Canary deployment stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceGroupCanaryDeployStageExecutionProgress object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.ComputeInstanceGroupCanaryDeployStageExecutionProgress.deploy_stage_type` attribute
        of this class is ``COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_stage_display_name:
            The value to assign to the deploy_stage_display_name property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type deploy_stage_display_name: str

        :param deploy_stage_type:
            The value to assign to the deploy_stage_type property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type deploy_stage_type: str

        :param deploy_stage_id:
            The value to assign to the deploy_stage_id property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type deploy_stage_id: str

        :param time_started:
            The value to assign to the time_started property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type time_finished: datetime

        :param status:
            The value to assign to the status property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "ROLLBACK_IN_PROGRESS", "ROLLBACK_SUCCEEDED", "ROLLBACK_FAILED"
        :type status: str

        :param deploy_stage_predecessors:
            The value to assign to the deploy_stage_predecessors property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type deploy_stage_predecessors: oci.devops.models.DeployStagePredecessorCollection

        :param deploy_stage_execution_progress_details:
            The value to assign to the deploy_stage_execution_progress_details property of this ComputeInstanceGroupCanaryDeployStageExecutionProgress.
        :type deploy_stage_execution_progress_details: list[oci.devops.models.DeployStageExecutionProgressDetails]

        """
        self.swagger_types = {
            'deploy_stage_display_name': 'str',
            'deploy_stage_type': 'str',
            'deploy_stage_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'status': 'str',
            'deploy_stage_predecessors': 'DeployStagePredecessorCollection',
            'deploy_stage_execution_progress_details': 'list[DeployStageExecutionProgressDetails]'
        }

        self.attribute_map = {
            'deploy_stage_display_name': 'deployStageDisplayName',
            'deploy_stage_type': 'deployStageType',
            'deploy_stage_id': 'deployStageId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'status': 'status',
            'deploy_stage_predecessors': 'deployStagePredecessors',
            'deploy_stage_execution_progress_details': 'deployStageExecutionProgressDetails'
        }

        self._deploy_stage_display_name = None
        self._deploy_stage_type = None
        self._deploy_stage_id = None
        self._time_started = None
        self._time_finished = None
        self._status = None
        self._deploy_stage_predecessors = None
        self._deploy_stage_execution_progress_details = None
        self._deploy_stage_type = 'COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemOptions(object):
    """
    The DB system options.
    """

    #: A constant which can be used with the storage_management property of a DbSystemOptions.
    #: This constant has a value of "ASM"
    STORAGE_MANAGEMENT_ASM = "ASM"

    #: A constant which can be used with the storage_management property of a DbSystemOptions.
    #: This constant has a value of "LVM"
    STORAGE_MANAGEMENT_LVM = "LVM"

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param storage_management:
            The value to assign to the storage_management property of this DbSystemOptions.
            Allowed values for this property are: "ASM", "LVM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type storage_management: str

        """
        self.swagger_types = {
            'storage_management': 'str'
        }

        self.attribute_map = {
            'storage_management': 'storageManagement'
        }

        self._storage_management = None

    @property
    def storage_management(self):
        """
        Gets the storage_management of this DbSystemOptions.
        The storage option used in DB system.
        ASM - Automatic storage management
        LVM - Logical Volume management

        Allowed values for this property are: "ASM", "LVM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The storage_management of this DbSystemOptions.
        :rtype: str
        """
        return self._storage_management

    @storage_management.setter
    def storage_management(self, storage_management):
        """
        Sets the storage_management of this DbSystemOptions.
        The storage option used in DB system.
        ASM - Automatic storage management
        LVM - Logical Volume management


        :param storage_management: The storage_management of this DbSystemOptions.
        :type: str
        """
        allowed_values = ["ASM", "LVM"]
        if not value_allowed_none_or_none_sentinel(storage_management, allowed_values):
            storage_management = 'UNKNOWN_ENUM_VALUE'
        self._storage_management = storage_management

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VirtualCircuitPublicPrefix(object):
    """
    A public IP prefix and its details. With a public virtual circuit, the customer
    specifies the customer-owned public IP prefixes to advertise across the connection.
    For more information, see `FastConnect Overview`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm
    """

    #: A constant which can be used with the verification_state property of a VirtualCircuitPublicPrefix.
    #: This constant has a value of "IN_PROGRESS"
    VERIFICATION_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the verification_state property of a VirtualCircuitPublicPrefix.
    #: This constant has a value of "COMPLETED"
    VERIFICATION_STATE_COMPLETED = "COMPLETED"

    #: A constant which can be used with the verification_state property of a VirtualCircuitPublicPrefix.
    #: This constant has a value of "FAILED"
    VERIFICATION_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VirtualCircuitPublicPrefix object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cidr_block:
            The value to assign to the cidr_block property of this VirtualCircuitPublicPrefix.
        :type cidr_block: str

        :param verification_state:
            The value to assign to the verification_state property of this VirtualCircuitPublicPrefix.
            Allowed values for this property are: "IN_PROGRESS", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type verification_state: str

        """
        self.swagger_types = {
            'cidr_block': 'str',
            'verification_state': 'str'
        }

        self.attribute_map = {
            'cidr_block': 'cidrBlock',
            'verification_state': 'verificationState'
        }

        self._cidr_block = None
        self._verification_state = None

    @property
    def cidr_block(self):
        """
        **[Required]** Gets the cidr_block of this VirtualCircuitPublicPrefix.
        Publix IP prefix (CIDR) that the customer specified.


        :return: The cidr_block of this VirtualCircuitPublicPrefix.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this VirtualCircuitPublicPrefix.
        Publix IP prefix (CIDR) that the customer specified.


        :param cidr_block: The cidr_block of this VirtualCircuitPublicPrefix.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def verification_state(self):
        """
        **[Required]** Gets the verification_state of this VirtualCircuitPublicPrefix.
        Oracle must verify that the customer owns the public IP prefix before traffic
        for that prefix can flow across the virtual circuit. Verification can take a
        few business days. `IN_PROGRESS` means Oracle is verifying the prefix. `COMPLETED`
        means verification succeeded. `FAILED` means verification failed and traffic for
        this prefix will not flow across the connection.

        Allowed values for this property are: "IN_PROGRESS", "COMPLETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The verification_state of this VirtualCircuitPublicPrefix.
        :rtype: str
        """
        return self._verification_state

    @verification_state.setter
    def verification_state(self, verification_state):
        """
        Sets the verification_state of this VirtualCircuitPublicPrefix.
        Oracle must verify that the customer owns the public IP prefix before traffic
        for that prefix can flow across the virtual circuit. Verification can take a
        few business days. `IN_PROGRESS` means Oracle is verifying the prefix. `COMPLETED`
        means verification succeeded. `FAILED` means verification failed and traffic for
        this prefix will not flow across the connection.


        :param verification_state: The verification_state of this VirtualCircuitPublicPrefix.
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "COMPLETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(verification_state, allowed_values):
            verification_state = 'UNKNOWN_ENUM_VALUE'
        self._verification_state = verification_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HcxLicenseSummary(object):
    """
    HCX on-premise license information summary.
    """

    #: A constant which can be used with the status property of a HcxLicenseSummary.
    #: This constant has a value of "AVAILABLE"
    STATUS_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the status property of a HcxLicenseSummary.
    #: This constant has a value of "CONSUMED"
    STATUS_CONSUMED = "CONSUMED"

    #: A constant which can be used with the status property of a HcxLicenseSummary.
    #: This constant has a value of "DEACTIVATED"
    STATUS_DEACTIVATED = "DEACTIVATED"

    #: A constant which can be used with the status property of a HcxLicenseSummary.
    #: This constant has a value of "DELETED"
    STATUS_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new HcxLicenseSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param activation_key:
            The value to assign to the activation_key property of this HcxLicenseSummary.
        :type activation_key: str

        :param status:
            The value to assign to the status property of this HcxLicenseSummary.
            Allowed values for this property are: "AVAILABLE", "CONSUMED", "DEACTIVATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param system_name:
            The value to assign to the system_name property of this HcxLicenseSummary.
        :type system_name: str

        """
        self.swagger_types = {
            'activation_key': 'str',
            'status': 'str',
            'system_name': 'str'
        }

        self.attribute_map = {
            'activation_key': 'activationKey',
            'status': 'status',
            'system_name': 'systemName'
        }

        self._activation_key = None
        self._status = None
        self._system_name = None

    @property
    def activation_key(self):
        """
        **[Required]** Gets the activation_key of this HcxLicenseSummary.
        HCX on-premise license key value


        :return: The activation_key of this HcxLicenseSummary.
        :rtype: str
        """
        return self._activation_key

    @activation_key.setter
    def activation_key(self, activation_key):
        """
        Sets the activation_key of this HcxLicenseSummary.
        HCX on-premise license key value


        :param activation_key: The activation_key of this HcxLicenseSummary.
        :type: str
        """
        self._activation_key = activation_key

    @property
    def status(self):
        """
        **[Required]** Gets the status of this HcxLicenseSummary.
        status of HCX on-premise license

        Allowed values for this property are: "AVAILABLE", "CONSUMED", "DEACTIVATED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this HcxLicenseSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this HcxLicenseSummary.
        status of HCX on-premise license


        :param status: The status of this HcxLicenseSummary.
        :type: str
        """
        allowed_values = ["AVAILABLE", "CONSUMED", "DEACTIVATED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def system_name(self):
        """
        Gets the system_name of this HcxLicenseSummary.
        Name of the system that consumed the HCX on-premise license


        :return: The system_name of this HcxLicenseSummary.
        :rtype: str
        """
        return self._system_name

    @system_name.setter
    def system_name(self, system_name):
        """
        Sets the system_name of this HcxLicenseSummary.
        Name of the system that consumed the HCX on-premise license


        :param system_name: The system_name of this HcxLicenseSummary.
        :type: str
        """
        self._system_name = system_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Capacity(object):
    """
    Capacity limits for the instance pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Capacity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param max:
            The value to assign to the max property of this Capacity.
        :type max: int

        :param min:
            The value to assign to the min property of this Capacity.
        :type min: int

        :param initial:
            The value to assign to the initial property of this Capacity.
        :type initial: int

        """
        self.swagger_types = {
            'max': 'int',
            'min': 'int',
            'initial': 'int'
        }

        self.attribute_map = {
            'max': 'max',
            'min': 'min',
            'initial': 'initial'
        }

        self._max = None
        self._min = None
        self._initial = None

    @property
    def max(self):
        """
        Gets the max of this Capacity.
        For a threshold-based autoscaling policy, this value is the maximum number of instances the instance pool is allowed
        to increase to (scale out).

        For a schedule-based autoscaling policy, this value is not used.


        :return: The max of this Capacity.
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this Capacity.
        For a threshold-based autoscaling policy, this value is the maximum number of instances the instance pool is allowed
        to increase to (scale out).

        For a schedule-based autoscaling policy, this value is not used.


        :param max: The max of this Capacity.
        :type: int
        """
        self._max = max

    @property
    def min(self):
        """
        Gets the min of this Capacity.
        For a threshold-based autoscaling policy, this value is the minimum number of instances the instance pool is allowed
        to decrease to (scale in).

        For a schedule-based autoscaling policy, this value is not used.


        :return: The min of this Capacity.
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this Capacity.
        For a threshold-based autoscaling policy, this value is the minimum number of instances the instance pool is allowed
        to decrease to (scale in).

        For a schedule-based autoscaling policy, this value is not used.


        :param min: The min of this Capacity.
        :type: int
        """
        self._min = min

    @property
    def initial(self):
        """
        Gets the initial of this Capacity.
        For a threshold-based autoscaling policy, this value is the initial number of instances to launch in the instance pool
        immediately after autoscaling is enabled. After autoscaling retrieves performance metrics, the number of
        instances is automatically adjusted from this initial number to a number that is based on the limits that
        you set.

        For a schedule-based autoscaling policy, this value is the target pool size to scale to when executing the schedule
        that's defined in the autoscaling policy.


        :return: The initial of this Capacity.
        :rtype: int
        """
        return self._initial

    @initial.setter
    def initial(self, initial):
        """
        Sets the initial of this Capacity.
        For a threshold-based autoscaling policy, this value is the initial number of instances to launch in the instance pool
        immediately after autoscaling is enabled. After autoscaling retrieves performance metrics, the number of
        instances is automatically adjusted from this initial number to a number that is based on the limits that
        you set.

        For a schedule-based autoscaling policy, this value is the target pool size to scale to when executing the schedule
        that's defined in the autoscaling policy.


        :param initial: The initial of this Capacity.
        :type: int
        """
        self._initial = initial

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestResource(object):
    """
    A resource created, operated on or used by a work request.
    """

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "CREATED"
    ACTION_TYPE_CREATED = "CREATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "UPDATED"
    ACTION_TYPE_UPDATED = "UPDATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "DELETED"
    ACTION_TYPE_DELETED = "DELETED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "FAILED"
    ACTION_TYPE_FAILED = "FAILED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "IN_PROGRESS"
    ACTION_TYPE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "INSTALLED"
    ACTION_TYPE_INSTALLED = "INSTALLED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "REMOVED"
    ACTION_TYPE_REMOVED = "REMOVED"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this WorkRequestResource.
        :type entity_type: str

        :param action_type:
            The value to assign to the action_type property of this WorkRequestResource.
            Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "FAILED", "IN_PROGRESS", "INSTALLED", "REMOVED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_type: str

        :param identifier:
            The value to assign to the identifier property of this WorkRequestResource.
        :type identifier: str

        :param name:
            The value to assign to the name property of this WorkRequestResource.
        :type name: str

        :param entity_uri:
            The value to assign to the entity_uri property of this WorkRequestResource.
        :type entity_uri: str

        """
        self.swagger_types = {
            'entity_type': 'str',
            'action_type': 'str',
            'identifier': 'str',
            'name': 'str',
            'entity_uri': 'str'
        }

        self.attribute_map = {
            'entity_type': 'entityType',
            'action_type': 'actionType',
            'identifier': 'identifier',
            'name': 'name',
            'entity_uri': 'entityUri'
        }

        self._entity_type = None
        self._action_type = None
        self._identifier = None
        self._name = None
        self._entity_uri = None

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this WorkRequestResource.
        The resource type for the work request.


        :return: The entity_type of this WorkRequestResource.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this WorkRequestResource.
        The resource type for the work request.


        :param entity_type: The entity_type of this WorkRequestResource.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def action_type(self):
        """
        **[Required]** Gets the action_type of this WorkRequestResource.
        The way in which this resource is affected by the work tracked in the work request.
        A resource being created, updated, or deleted will remain in the IN_PROGRESS state until
        work is complete for that resource at which point it will transition to CREATED, UPDATED,
        or DELETED, respectively. If the request failed for that resource,
        the state will be FAILED.

        Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "FAILED", "IN_PROGRESS", "INSTALLED", "REMOVED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_type of this WorkRequestResource.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this WorkRequestResource.
        The way in which this resource is affected by the work tracked in the work request.
        A resource being created, updated, or deleted will remain in the IN_PROGRESS state until
        work is complete for that resource at which point it will transition to CREATED, UPDATED,
        or DELETED, respectively. If the request failed for that resource,
        the state will be FAILED.


        :param action_type: The action_type of this WorkRequestResource.
        :type: str
        """
        allowed_values = ["CREATED", "UPDATED", "DELETED", "FAILED", "IN_PROGRESS", "INSTALLED", "REMOVED"]
        if not value_allowed_none_or_none_sentinel(action_type, allowed_values):
            action_type = 'UNKNOWN_ENUM_VALUE'
        self._action_type = action_type

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this WorkRequestResource.
        The identifier of the resource. Not all resources will have an id.


        :return: The identifier of this WorkRequestResource.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this WorkRequestResource.
        The identifier of the resource. Not all resources will have an id.


        :param identifier: The identifier of this WorkRequestResource.
        :type: str
        """
        self._identifier = identifier

    @property
    def name(self):
        """
        Gets the name of this WorkRequestResource.
        The name of the resource. Not all resources will have a name specified.


        :return: The name of this WorkRequestResource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkRequestResource.
        The name of the resource. Not all resources will have a name specified.


        :param name: The name of this WorkRequestResource.
        :type: str
        """
        self._name = name

    @property
    def entity_uri(self):
        """
        **[Required]** Gets the entity_uri of this WorkRequestResource.
        The URI path that the user can do a GET on to access the resource metadata.


        :return: The entity_uri of this WorkRequestResource.
        :rtype: str
        """
        return self._entity_uri

    @entity_uri.setter
    def entity_uri(self, entity_uri):
        """
        Sets the entity_uri of this WorkRequestResource.
        The URI path that the user can do a GET on to access the resource metadata.


        :param entity_uri: The entity_uri of this WorkRequestResource.
        :type: str
        """
        self._entity_uri = entity_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_deploy_stage_details import UpdateDeployStageDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateComputeInstanceGroupDeployStageDetails(UpdateDeployStageDetails):
    """
    Specifies the instance group rolling deployment stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateComputeInstanceGroupDeployStageDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.UpdateComputeInstanceGroupDeployStageDetails.deploy_stage_type` attribute
        of this class is ``COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type display_name: str

        :param deploy_stage_type:
            The value to assign to the deploy_stage_type property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type deploy_stage_type: str

        :param deploy_stage_predecessor_collection:
            The value to assign to the deploy_stage_predecessor_collection property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type deploy_stage_predecessor_collection: oci.devops.models.DeployStagePredecessorCollection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param compute_instance_group_deploy_environment_id:
            The value to assign to the compute_instance_group_deploy_environment_id property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type compute_instance_group_deploy_environment_id: str

        :param deployment_spec_deploy_artifact_id:
            The value to assign to the deployment_spec_deploy_artifact_id property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type deployment_spec_deploy_artifact_id: str

        :param deploy_artifact_ids:
            The value to assign to the deploy_artifact_ids property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type deploy_artifact_ids: list[str]

        :param rollout_policy:
            The value to assign to the rollout_policy property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type rollout_policy: oci.devops.models.ComputeInstanceGroupRolloutPolicy

        :param rollback_policy:
            The value to assign to the rollback_policy property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type rollback_policy: oci.devops.models.DeployStageRollbackPolicy

        :param failure_policy:
            The value to assign to the failure_policy property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type failure_policy: oci.devops.models.ComputeInstanceGroupFailurePolicy

        :param load_balancer_config:
            The value to assign to the load_balancer_config property of this UpdateComputeInstanceGroupDeployStageDetails.
        :type load_balancer_config: oci.devops.models.LoadBalancerConfig

        """
        self.swagger_types = {
            'description': 'str',
            'display_name': 'str',
            'deploy_stage_type': 'str',
            'deploy_stage_predecessor_collection': 'DeployStagePredecessorCollection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'compute_instance_group_deploy_environment_id': 'str',
            'deployment_spec_deploy_artifact_id': 'str',
            'deploy_artifact_ids': 'list[str]',
            'rollout_policy': 'ComputeInstanceGroupRolloutPolicy',
            'rollback_policy': 'DeployStageRollbackPolicy',
            'failure_policy': 'ComputeInstanceGroupFailurePolicy',
            'load_balancer_config': 'LoadBalancerConfig'
        }

        self.attribute_map = {
            'description': 'description',
            'display_name': 'displayName',
            'deploy_stage_type': 'deployStageType',
            'deploy_stage_predecessor_collection': 'deployStagePredecessorCollection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'compute_instance_group_deploy_environment_id': 'computeInstanceGroupDeployEnvironmentId',
            'deployment_spec_deploy_artifact_id': 'deploymentSpecDeployArtifactId',
            'deploy_artifact_ids': 'deployArtifactIds',
            'rollout_policy': 'rolloutPolicy',
            'rollback_policy': 'rollbackPolicy',
            'failure_policy': 'failurePolicy',
            'load_balancer_config': 'loadBalancerConfig'
        }

        self._description = None
        self._display_name = None
        self._deploy_stage_type = None
        self._deploy_stage_predecessor_collection = None
        self._freeform_tags = None
        self._defined_tags = None
        self._compute_instance_group_deploy_environment_id = None
        self._deployment_spec_deploy_artifact_id = None
        self._deploy_artifact_ids = None
        self._rollout_policy = None
        self._rollback_policy = None
        self._failure_policy = None
        self._load_balancer_config = None
        self._deploy_stage_type = 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT'

    @property
    def compute_instance_group_deploy_environment_id(self):
        """
        Gets the compute_instance_group_deploy_environment_id of this UpdateComputeInstanceGroupDeployStageDetails.
        A compute instance group environment OCID for rolling deployment.


        :return: The compute_instance_group_deploy_environment_id of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: str
        """
        return self._compute_instance_group_deploy_environment_id

    @compute_instance_group_deploy_environment_id.setter
    def compute_instance_group_deploy_environment_id(self, compute_instance_group_deploy_environment_id):
        """
        Sets the compute_instance_group_deploy_environment_id of this UpdateComputeInstanceGroupDeployStageDetails.
        A compute instance group environment OCID for rolling deployment.


        :param compute_instance_group_deploy_environment_id: The compute_instance_group_deploy_environment_id of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: str
        """
        self._compute_instance_group_deploy_environment_id = compute_instance_group_deploy_environment_id

    @property
    def deployment_spec_deploy_artifact_id(self):
        """
        Gets the deployment_spec_deploy_artifact_id of this UpdateComputeInstanceGroupDeployStageDetails.
        The OCID of the artifact that contains the deployment specification.


        :return: The deployment_spec_deploy_artifact_id of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: str
        """
        return self._deployment_spec_deploy_artifact_id

    @deployment_spec_deploy_artifact_id.setter
    def deployment_spec_deploy_artifact_id(self, deployment_spec_deploy_artifact_id):
        """
        Sets the deployment_spec_deploy_artifact_id of this UpdateComputeInstanceGroupDeployStageDetails.
        The OCID of the artifact that contains the deployment specification.


        :param deployment_spec_deploy_artifact_id: The deployment_spec_deploy_artifact_id of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: str
        """
        self._deployment_spec_deploy_artifact_id = deployment_spec_deploy_artifact_id

    @property
    def deploy_artifact_ids(self):
        """
        Gets the deploy_artifact_ids of this UpdateComputeInstanceGroupDeployStageDetails.
        Additional file artifact OCIDs.


        :return: The deploy_artifact_ids of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: list[str]
        """
        return self._deploy_artifact_ids

    @deploy_artifact_ids.setter
    def deploy_artifact_ids(self, deploy_artifact_ids):
        """
        Sets the deploy_artifact_ids of this UpdateComputeInstanceGroupDeployStageDetails.
        Additional file artifact OCIDs.


        :param deploy_artifact_ids: The deploy_artifact_ids of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: list[str]
        """
        self._deploy_artifact_ids = deploy_artifact_ids

    @property
    def rollout_policy(self):
        """
        Gets the rollout_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :return: The rollout_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: oci.devops.models.ComputeInstanceGroupRolloutPolicy
        """
        return self._rollout_policy

    @rollout_policy.setter
    def rollout_policy(self, rollout_policy):
        """
        Sets the rollout_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :param rollout_policy: The rollout_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: oci.devops.models.ComputeInstanceGroupRolloutPolicy
        """
        self._rollout_policy = rollout_policy

    @property
    def rollback_policy(self):
        """
        Gets the rollback_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :return: The rollback_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: oci.devops.models.DeployStageRollbackPolicy
        """
        return self._rollback_policy

    @rollback_policy.setter
    def rollback_policy(self, rollback_policy):
        """
        Sets the rollback_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :param rollback_policy: The rollback_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: oci.devops.models.DeployStageRollbackPolicy
        """
        self._rollback_policy = rollback_policy

    @property
    def failure_policy(self):
        """
        Gets the failure_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :return: The failure_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: oci.devops.models.ComputeInstanceGroupFailurePolicy
        """
        return self._failure_policy

    @failure_policy.setter
    def failure_policy(self, failure_policy):
        """
        Sets the failure_policy of this UpdateComputeInstanceGroupDeployStageDetails.

        :param failure_policy: The failure_policy of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: oci.devops.models.ComputeInstanceGroupFailurePolicy
        """
        self._failure_policy = failure_policy

    @property
    def load_balancer_config(self):
        """
        Gets the load_balancer_config of this UpdateComputeInstanceGroupDeployStageDetails.

        :return: The load_balancer_config of this UpdateComputeInstanceGroupDeployStageDetails.
        :rtype: oci.devops.models.LoadBalancerConfig
        """
        return self._load_balancer_config

    @load_balancer_config.setter
    def load_balancer_config(self, load_balancer_config):
        """
        Sets the load_balancer_config of this UpdateComputeInstanceGroupDeployStageDetails.

        :param load_balancer_config: The load_balancer_config of this UpdateComputeInstanceGroupDeployStageDetails.
        :type: oci.devops.models.LoadBalancerConfig
        """
        self._load_balancer_config = load_balancer_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .mbcharsetprober import MultiByteCharSetProber
from .codingstatemachine import CodingStateMachine
from .chardistribution import SJISDistributionAnalysis
from .jpcntx import SJISContextAnalysis
from .mbcssm import SJIS_SM_MODEL
from .enums import ProbingState, MachineState


class SJISProber(MultiByteCharSetProber):
    def __init__(self):
        super(SJISProber, self).__init__()
        self.coding_sm = CodingStateMachine(SJIS_SM_MODEL)
        self.distribution_analyzer = SJISDistributionAnalysis()
        self.context_analyzer = SJISContextAnalysis()
        self.reset()

    def reset(self):
        super(SJISProber, self).reset()
        self.context_analyzer.reset()

    @property
    def charset_name(self):
        return self.context_analyzer.charset_name

    @property
    def language(self):
        return "Japanese"

    def feed(self, byte_str):
        for i in range(len(byte_str)):
            coding_state = self.coding_sm.next_state(byte_str[i])
            if coding_state == MachineState.ERROR:
                self.logger.debug('%s %s prober hit error at byte %s',
                                  self.charset_name, self.language, i)
                self._state = ProbingState.NOT_ME
                break
            elif coding_state == MachineState.ITS_ME:
                self._state = ProbingState.FOUND_IT
                break
            elif coding_state == MachineState.START:
                char_len = self.coding_sm.get_current_charlen()
                if i == 0:
                    self._last_char[1] = byte_str[0]
                    self.context_analyzer.feed(self._last_char[2 - char_len:],
                                               char_len)
                    self.distribution_analyzer.feed(self._last_char, char_len)
                else:
                    self.context_analyzer.feed(byte_str[i + 1 - char_len:i + 3
                                                        - char_len], char_len)
                    self.distribution_analyzer.feed(byte_str[i - 1:i + 1],
                                                    char_len)

        self._last_char[0] = byte_str[-1]

        if self.state == ProbingState.DETECTING:
            if (self.context_analyzer.got_enough_data() and
               (self.get_confidence() > self.SHORTCUT_THRESHOLD)):
                self._state = ProbingState.FOUND_IT

        return self.state

    def get_confidence(self):
        context_conf = self.context_analyzer.get_confidence()
        distrib_conf = self.distribution_analyzer.get_confidence()
        return max(context_conf, distrib_conf)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .base_announcements_preferences import BaseAnnouncementsPreferences
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnnouncementsPreferencesSummary(BaseAnnouncementsPreferences):
    """
    The summary object for announcement email preferences.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnnouncementsPreferencesSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.announcements_service.models.AnnouncementsPreferencesSummary.type` attribute
        of this class is ``AnnouncementsPreferencesSummary`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AnnouncementsPreferencesSummary.
        :type type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AnnouncementsPreferencesSummary.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this AnnouncementsPreferencesSummary.
        :type id: str

        :param is_unsubscribed:
            The value to assign to the is_unsubscribed property of this AnnouncementsPreferencesSummary.
        :type is_unsubscribed: bool

        :param time_created:
            The value to assign to the time_created property of this AnnouncementsPreferencesSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this AnnouncementsPreferencesSummary.
        :type time_updated: datetime

        :param preference_type:
            The value to assign to the preference_type property of this AnnouncementsPreferencesSummary.
        :type preference_type: str

        """
        self.swagger_types = {
            'type': 'str',
            'compartment_id': 'str',
            'id': 'str',
            'is_unsubscribed': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'preference_type': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'compartment_id': 'compartmentId',
            'id': 'id',
            'is_unsubscribed': 'isUnsubscribed',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'preference_type': 'preferenceType'
        }

        self._type = None
        self._compartment_id = None
        self._id = None
        self._is_unsubscribed = None
        self._time_created = None
        self._time_updated = None
        self._preference_type = None
        self._type = 'AnnouncementsPreferencesSummary'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FleetAgentConfiguration(object):
    """
    Management Agent Configuration for a Fleet. Includes JRE scanning frequency and list of include/exclude file system paths.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FleetAgentConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param jre_scan_frequency_in_minutes:
            The value to assign to the jre_scan_frequency_in_minutes property of this FleetAgentConfiguration.
        :type jre_scan_frequency_in_minutes: int

        :param java_usage_tracker_processing_frequency_in_minutes:
            The value to assign to the java_usage_tracker_processing_frequency_in_minutes property of this FleetAgentConfiguration.
        :type java_usage_tracker_processing_frequency_in_minutes: int

        :param linux_configuration:
            The value to assign to the linux_configuration property of this FleetAgentConfiguration.
        :type linux_configuration: oci.jms.models.FleetAgentOsConfiguration

        :param windows_configuration:
            The value to assign to the windows_configuration property of this FleetAgentConfiguration.
        :type windows_configuration: oci.jms.models.FleetAgentOsConfiguration

        :param time_last_modified:
            The value to assign to the time_last_modified property of this FleetAgentConfiguration.
        :type time_last_modified: datetime

        """
        self.swagger_types = {
            'jre_scan_frequency_in_minutes': 'int',
            'java_usage_tracker_processing_frequency_in_minutes': 'int',
            'linux_configuration': 'FleetAgentOsConfiguration',
            'windows_configuration': 'FleetAgentOsConfiguration',
            'time_last_modified': 'datetime'
        }

        self.attribute_map = {
            'jre_scan_frequency_in_minutes': 'jreScanFrequencyInMinutes',
            'java_usage_tracker_processing_frequency_in_minutes': 'javaUsageTrackerProcessingFrequencyInMinutes',
            'linux_configuration': 'linuxConfiguration',
            'windows_configuration': 'windowsConfiguration',
            'time_last_modified': 'timeLastModified'
        }

        self._jre_scan_frequency_in_minutes = None
        self._java_usage_tracker_processing_frequency_in_minutes = None
        self._linux_configuration = None
        self._windows_configuration = None
        self._time_last_modified = None

    @property
    def jre_scan_frequency_in_minutes(self):
        """
        **[Required]** Gets the jre_scan_frequency_in_minutes of this FleetAgentConfiguration.
        The frequency (in minutes) of JRE scanning. (That is, how often should JMS scan for JRE installations.)


        :return: The jre_scan_frequency_in_minutes of this FleetAgentConfiguration.
        :rtype: int
        """
        return self._jre_scan_frequency_in_minutes

    @jre_scan_frequency_in_minutes.setter
    def jre_scan_frequency_in_minutes(self, jre_scan_frequency_in_minutes):
        """
        Sets the jre_scan_frequency_in_minutes of this FleetAgentConfiguration.
        The frequency (in minutes) of JRE scanning. (That is, how often should JMS scan for JRE installations.)


        :param jre_scan_frequency_in_minutes: The jre_scan_frequency_in_minutes of this FleetAgentConfiguration.
        :type: int
        """
        self._jre_scan_frequency_in_minutes = jre_scan_frequency_in_minutes

    @property
    def java_usage_tracker_processing_frequency_in_minutes(self):
        """
        **[Required]** Gets the java_usage_tracker_processing_frequency_in_minutes of this FleetAgentConfiguration.
        The frequency (in minutes) of Java Usage Tracker processing. (That is, how often should JMS process data from the Java Usage Tracker.)


        :return: The java_usage_tracker_processing_frequency_in_minutes of this FleetAgentConfiguration.
        :rtype: int
        """
        return self._java_usage_tracker_processing_frequency_in_minutes

    @java_usage_tracker_processing_frequency_in_minutes.setter
    def java_usage_tracker_processing_frequency_in_minutes(self, java_usage_tracker_processing_frequency_in_minutes):
        """
        Sets the java_usage_tracker_processing_frequency_in_minutes of this FleetAgentConfiguration.
        The frequency (in minutes) of Java Usage Tracker processing. (That is, how often should JMS process data from the Java Usage Tracker.)


        :param java_usage_tracker_processing_frequency_in_minutes: The java_usage_tracker_processing_frequency_in_minutes of this FleetAgentConfiguration.
        :type: int
        """
        self._java_usage_tracker_processing_frequency_in_minutes = java_usage_tracker_processing_frequency_in_minutes

    @property
    def linux_configuration(self):
        """
        **[Required]** Gets the linux_configuration of this FleetAgentConfiguration.

        :return: The linux_configuration of this FleetAgentConfiguration.
        :rtype: oci.jms.models.FleetAgentOsConfiguration
        """
        return self._linux_configuration

    @linux_configuration.setter
    def linux_configuration(self, linux_configuration):
        """
        Sets the linux_configuration of this FleetAgentConfiguration.

        :param linux_configuration: The linux_configuration of this FleetAgentConfiguration.
        :type: oci.jms.models.FleetAgentOsConfiguration
        """
        self._linux_configuration = linux_configuration

    @property
    def windows_configuration(self):
        """
        **[Required]** Gets the windows_configuration of this FleetAgentConfiguration.

        :return: The windows_configuration of this FleetAgentConfiguration.
        :rtype: oci.jms.models.FleetAgentOsConfiguration
        """
        return self._windows_configuration

    @windows_configuration.setter
    def windows_configuration(self, windows_configuration):
        """
        Sets the windows_configuration of this FleetAgentConfiguration.

        :param windows_configuration: The windows_configuration of this FleetAgentConfiguration.
        :type: oci.jms.models.FleetAgentOsConfiguration
        """
        self._windows_configuration = windows_configuration

    @property
    def time_last_modified(self):
        """
        **[Required]** Gets the time_last_modified of this FleetAgentConfiguration.
        The date and time of the last modification to the Fleet Agent Configuration (formatted according to `RFC3339`__).

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_last_modified of this FleetAgentConfiguration.
        :rtype: datetime
        """
        return self._time_last_modified

    @time_last_modified.setter
    def time_last_modified(self, time_last_modified):
        """
        Sets the time_last_modified of this FleetAgentConfiguration.
        The date and time of the last modification to the Fleet Agent Configuration (formatted according to `RFC3339`__).

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_last_modified: The time_last_modified of this FleetAgentConfiguration.
        :type: datetime
        """
        self._time_last_modified = time_last_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .flow_port_link import FlowPortLink
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConditionalInputLink(FlowPortLink):
    """
    The information about the conditional input link.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConditionalInputLink object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.ConditionalInputLink.model_type` attribute
        of this class is ``CONDITIONAL_INPUT_LINK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this ConditionalInputLink.
            Allowed values for this property are: "CONDITIONAL_INPUT_LINK", "OUTPUT_LINK", "INPUT_LINK"
        :type model_type: str

        :param key:
            The value to assign to the key property of this ConditionalInputLink.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this ConditionalInputLink.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ConditionalInputLink.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param object_status:
            The value to assign to the object_status property of this ConditionalInputLink.
        :type object_status: int

        :param description:
            The value to assign to the description property of this ConditionalInputLink.
        :type description: str

        :param port:
            The value to assign to the port property of this ConditionalInputLink.
        :type port: str

        :param from_link:
            The value to assign to the from_link property of this ConditionalInputLink.
        :type from_link: oci.data_integration.models.OutputLink

        :param field_map:
            The value to assign to the field_map property of this ConditionalInputLink.
        :type field_map: oci.data_integration.models.FieldMap

        :param condition:
            The value to assign to the condition property of this ConditionalInputLink.
        :type condition: oci.data_integration.models.Expression

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'object_status': 'int',
            'description': 'str',
            'port': 'str',
            'from_link': 'OutputLink',
            'field_map': 'FieldMap',
            'condition': 'Expression'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'object_status': 'objectStatus',
            'description': 'description',
            'port': 'port',
            'from_link': 'fromLink',
            'field_map': 'fieldMap',
            'condition': 'condition'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._object_status = None
        self._description = None
        self._port = None
        self._from_link = None
        self._field_map = None
        self._condition = None
        self._model_type = 'CONDITIONAL_INPUT_LINK'

    @property
    def from_link(self):
        """
        Gets the from_link of this ConditionalInputLink.

        :return: The from_link of this ConditionalInputLink.
        :rtype: oci.data_integration.models.OutputLink
        """
        return self._from_link

    @from_link.setter
    def from_link(self, from_link):
        """
        Sets the from_link of this ConditionalInputLink.

        :param from_link: The from_link of this ConditionalInputLink.
        :type: oci.data_integration.models.OutputLink
        """
        self._from_link = from_link

    @property
    def field_map(self):
        """
        Gets the field_map of this ConditionalInputLink.

        :return: The field_map of this ConditionalInputLink.
        :rtype: oci.data_integration.models.FieldMap
        """
        return self._field_map

    @field_map.setter
    def field_map(self, field_map):
        """
        Sets the field_map of this ConditionalInputLink.

        :param field_map: The field_map of this ConditionalInputLink.
        :type: oci.data_integration.models.FieldMap
        """
        self._field_map = field_map

    @property
    def condition(self):
        """
        Gets the condition of this ConditionalInputLink.

        :return: The condition of this ConditionalInputLink.
        :rtype: oci.data_integration.models.Expression
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this ConditionalInputLink.

        :param condition: The condition of this ConditionalInputLink.
        :type: oci.data_integration.models.Expression
        """
        self._condition = condition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceReservationConfigDetails(object):
    """
    A template that contains the settings to use when defining the instance reservation configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceReservationConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_shape:
            The value to assign to the instance_shape property of this InstanceReservationConfigDetails.
        :type instance_shape: str

        :param instance_shape_config:
            The value to assign to the instance_shape_config property of this InstanceReservationConfigDetails.
        :type instance_shape_config: oci.core.models.InstanceReservationShapeConfigDetails

        :param fault_domain:
            The value to assign to the fault_domain property of this InstanceReservationConfigDetails.
        :type fault_domain: str

        :param reserved_count:
            The value to assign to the reserved_count property of this InstanceReservationConfigDetails.
        :type reserved_count: int

        """
        self.swagger_types = {
            'instance_shape': 'str',
            'instance_shape_config': 'InstanceReservationShapeConfigDetails',
            'fault_domain': 'str',
            'reserved_count': 'int'
        }

        self.attribute_map = {
            'instance_shape': 'instanceShape',
            'instance_shape_config': 'instanceShapeConfig',
            'fault_domain': 'faultDomain',
            'reserved_count': 'reservedCount'
        }

        self._instance_shape = None
        self._instance_shape_config = None
        self._fault_domain = None
        self._reserved_count = None

    @property
    def instance_shape(self):
        """
        **[Required]** Gets the instance_shape of this InstanceReservationConfigDetails.
        The shape requested when launching instances using reserved capacity.
        The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.
        You can list all available shapes by calling :class:`ListComputeCapacityReservationInstanceShapes`.


        :return: The instance_shape of this InstanceReservationConfigDetails.
        :rtype: str
        """
        return self._instance_shape

    @instance_shape.setter
    def instance_shape(self, instance_shape):
        """
        Sets the instance_shape of this InstanceReservationConfigDetails.
        The shape requested when launching instances using reserved capacity.
        The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.
        You can list all available shapes by calling :class:`ListComputeCapacityReservationInstanceShapes`.


        :param instance_shape: The instance_shape of this InstanceReservationConfigDetails.
        :type: str
        """
        self._instance_shape = instance_shape

    @property
    def instance_shape_config(self):
        """
        Gets the instance_shape_config of this InstanceReservationConfigDetails.

        :return: The instance_shape_config of this InstanceReservationConfigDetails.
        :rtype: oci.core.models.InstanceReservationShapeConfigDetails
        """
        return self._instance_shape_config

    @instance_shape_config.setter
    def instance_shape_config(self, instance_shape_config):
        """
        Sets the instance_shape_config of this InstanceReservationConfigDetails.

        :param instance_shape_config: The instance_shape_config of this InstanceReservationConfigDetails.
        :type: oci.core.models.InstanceReservationShapeConfigDetails
        """
        self._instance_shape_config = instance_shape_config

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this InstanceReservationConfigDetails.
        The fault domain to use for instances created using this reservation configuration.
        For more information, see `Fault Domains`__.
        If you do not specify the fault domain, the capacity is available for an instance
        that does not specify a fault domain. To change the fault domain for a reservation,
        delete the reservation and create a new one in the preferred fault domain.

        To retrieve a list of fault domains, use the `ListFaultDomains` operation in
        the `Identity and Access Management Service API`__.

        Example: `FAULT-DOMAIN-1`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm#fault
        __ https://docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/


        :return: The fault_domain of this InstanceReservationConfigDetails.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this InstanceReservationConfigDetails.
        The fault domain to use for instances created using this reservation configuration.
        For more information, see `Fault Domains`__.
        If you do not specify the fault domain, the capacity is available for an instance
        that does not specify a fault domain. To change the fault domain for a reservation,
        delete the reservation and create a new one in the preferred fault domain.

        To retrieve a list of fault domains, use the `ListFaultDomains` operation in
        the `Identity and Access Management Service API`__.

        Example: `FAULT-DOMAIN-1`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm#fault
        __ https://docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/


        :param fault_domain: The fault_domain of this InstanceReservationConfigDetails.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def reserved_count(self):
        """
        **[Required]** Gets the reserved_count of this InstanceReservationConfigDetails.
        The amount of capacity to reserve in this reservation configuration.


        :return: The reserved_count of this InstanceReservationConfigDetails.
        :rtype: int
        """
        return self._reserved_count

    @reserved_count.setter
    def reserved_count(self, reserved_count):
        """
        Sets the reserved_count of this InstanceReservationConfigDetails.
        The amount of capacity to reserve in this reservation configuration.


        :param reserved_count: The reserved_count of this InstanceReservationConfigDetails.
        :type: int
        """
        self._reserved_count = reserved_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LabelSourceSummary(object):
    """
    source summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LabelSourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_display_name:
            The value to assign to the source_display_name property of this LabelSourceSummary.
        :type source_display_name: str

        :param source_name:
            The value to assign to the source_name property of this LabelSourceSummary.
        :type source_name: str

        :param source_id:
            The value to assign to the source_id property of this LabelSourceSummary.
        :type source_id: int

        :param label_operator_name:
            The value to assign to the label_operator_name property of this LabelSourceSummary.
        :type label_operator_name: str

        :param label_condition:
            The value to assign to the label_condition property of this LabelSourceSummary.
        :type label_condition: str

        :param label_field_displayname:
            The value to assign to the label_field_displayname property of this LabelSourceSummary.
        :type label_field_displayname: str

        :param label_field_name:
            The value to assign to the label_field_name property of this LabelSourceSummary.
        :type label_field_name: str

        """
        self.swagger_types = {
            'source_display_name': 'str',
            'source_name': 'str',
            'source_id': 'int',
            'label_operator_name': 'str',
            'label_condition': 'str',
            'label_field_displayname': 'str',
            'label_field_name': 'str'
        }

        self.attribute_map = {
            'source_display_name': 'sourceDisplayName',
            'source_name': 'sourceName',
            'source_id': 'sourceId',
            'label_operator_name': 'labelOperatorName',
            'label_condition': 'labelCondition',
            'label_field_displayname': 'labelFieldDisplayname',
            'label_field_name': 'labelFieldName'
        }

        self._source_display_name = None
        self._source_name = None
        self._source_id = None
        self._label_operator_name = None
        self._label_condition = None
        self._label_field_displayname = None
        self._label_field_name = None

    @property
    def source_display_name(self):
        """
        Gets the source_display_name of this LabelSourceSummary.
        The source display name.


        :return: The source_display_name of this LabelSourceSummary.
        :rtype: str
        """
        return self._source_display_name

    @source_display_name.setter
    def source_display_name(self, source_display_name):
        """
        Sets the source_display_name of this LabelSourceSummary.
        The source display name.


        :param source_display_name: The source_display_name of this LabelSourceSummary.
        :type: str
        """
        self._source_display_name = source_display_name

    @property
    def source_name(self):
        """
        Gets the source_name of this LabelSourceSummary.
        The source internal name.


        :return: The source_name of this LabelSourceSummary.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this LabelSourceSummary.
        The source internal name.


        :param source_name: The source_name of this LabelSourceSummary.
        :type: str
        """
        self._source_name = source_name

    @property
    def source_id(self):
        """
        Gets the source_id of this LabelSourceSummary.
        The source unique identifier.


        :return: The source_id of this LabelSourceSummary.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LabelSourceSummary.
        The source unique identifier.


        :param source_id: The source_id of this LabelSourceSummary.
        :type: int
        """
        self._source_id = source_id

    @property
    def label_operator_name(self):
        """
        Gets the label_operator_name of this LabelSourceSummary.
        The label operator.


        :return: The label_operator_name of this LabelSourceSummary.
        :rtype: str
        """
        return self._label_operator_name

    @label_operator_name.setter
    def label_operator_name(self, label_operator_name):
        """
        Sets the label_operator_name of this LabelSourceSummary.
        The label operator.


        :param label_operator_name: The label_operator_name of this LabelSourceSummary.
        :type: str
        """
        self._label_operator_name = label_operator_name

    @property
    def label_condition(self):
        """
        Gets the label_condition of this LabelSourceSummary.
        The label condition.


        :return: The label_condition of this LabelSourceSummary.
        :rtype: str
        """
        return self._label_condition

    @label_condition.setter
    def label_condition(self, label_condition):
        """
        Sets the label_condition of this LabelSourceSummary.
        The label condition.


        :param label_condition: The label_condition of this LabelSourceSummary.
        :type: str
        """
        self._label_condition = label_condition

    @property
    def label_field_displayname(self):
        """
        Gets the label_field_displayname of this LabelSourceSummary.
        The label field display name.


        :return: The label_field_displayname of this LabelSourceSummary.
        :rtype: str
        """
        return self._label_field_displayname

    @label_field_displayname.setter
    def label_field_displayname(self, label_field_displayname):
        """
        Sets the label_field_displayname of this LabelSourceSummary.
        The label field display name.


        :param label_field_displayname: The label_field_displayname of this LabelSourceSummary.
        :type: str
        """
        self._label_field_displayname = label_field_displayname

    @property
    def label_field_name(self):
        """
        Gets the label_field_name of this LabelSourceSummary.
        The label field name.


        :return: The label_field_name of this LabelSourceSummary.
        :rtype: str
        """
        return self._label_field_name

    @label_field_name.setter
    def label_field_name(self, label_field_name):
        """
        Sets the label_field_name of this LabelSourceSummary.
        The label field name.


        :param label_field_name: The label_field_name of this LabelSourceSummary.
        :type: str
        """
        self._label_field_name = label_field_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
